==> apache-drill-1.20.1-src.tar.gz: apache-drill-1.20.1-src/exec/java-exec/src/main/java/org/apache/drill/exec/oauth/TokenRegistry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.oauth;

import java.util.Iterator;
import java.util.Map;

/**
 * Persistent Registry for OAuth Tokens
 */
public interface TokenRegistry extends AutoCloseable {

  /**
   * Creates a token table for specified {@code pluginName}.
   * @param pluginName The name of the plugin instance.
   */
  void createTokenTable(String pluginName);

  PersistentTokenTable getTokenTable(String name);

  /**
   * Deletes aliases table for specified {@code userName}.
   * @param pluginName name of the user whose aliases table should be removed
   */
  void deleteTokenTable(String pluginName);

  /**
   * Returns iterator for aliases table entries.
   */
  Iterator<Map.Entry<String, Tokens>> getAllTokens();
}

==> apache-drill-1.21.2-src.tar.gz: apache-drill-1.21.2-src/exec/java-exec/src/main/java/org/apache/drill/exec/oauth/TokenRegistry.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.oauth;

import java.util.Iterator;
import java.util.Map;

/**
 * Persistent Registry for OAuth Tokens
 */
public interface TokenRegistry extends AutoCloseable {

  /**
   * Creates a token table for specified {@code pluginName}.
   * @param pluginName The name of the plugin instance.
   */
  void createTokenTable(String pluginName);

  PersistentTokenTable getTokenTable(String name);

  /**
   * Deletes the token table for specified {@code pluginName}.
   * @param pluginName name of the plugin whose token table should be removed
   */
  void deleteTokenTable(String pluginName);

  /**
   * Returns iterator for aliases table entries.
   */
  Iterator<Map.Entry<String, Tokens>> getAllTokens();
}
